## What is it?
Simple library to test if python script is running in Spyder IDE

## Instalation
pip install check_spyder

## Dependencies
os

## License
MIT License

## Documentation
from check_spyder import Check_Spyder
check = Check_Spyder().is_spyder

Returns True if Spyder is present or False if not.
